==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebGridToolbarBaseActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebGridToolbarBaseActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridToolbarBaseActionDescriptionMetadata, _super);
    function WebGridToolbarBaseActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarBaseActionDescriptionMetadata.b = function (a) {
        if (WebGridToolbarBaseActionDescriptionMetadata.a == null) {
            WebGridToolbarBaseActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarBaseActionDescriptionMetadata.c(WebGridToolbarBaseActionDescriptionMetadata.a);
        }
        if (a.j(WebGridToolbarBaseActionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridToolbarBaseActionDescriptionMetadata.a);
    };
    WebGridToolbarBaseActionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridToolbarBaseAction");
        a.item("__tagNameWC", "String:igc-grid-toolbar-base-action");
        a.item("__manageCollectionInMarkup", "Boolean");
        a.item("Name", "String");
        WebGridToolbarBaseActionDescriptionMetadata.e(a);
    };
    WebGridToolbarBaseActionDescriptionMetadata.d = function (a) {
        WebGridToolbarBaseActionDescriptionMetadata.b(a);
        a.z("WebGridToolbarBaseAction", WebGridToolbarBaseActionDescriptionMetadata.a);
    };
    WebGridToolbarBaseActionDescriptionMetadata.e = function (a) {
        a.item("__tagNameWCSubstitutable", "String:igc-grid-toolbar-advanced-filtering,igc-grid-toolbar-exporter,igc-grid-toolbar-hiding,igc-grid-toolbar-pinning");
    };
    WebGridToolbarBaseActionDescriptionMetadata.$t = markType(WebGridToolbarBaseActionDescriptionMetadata, 'WebGridToolbarBaseActionDescriptionMetadata');
    WebGridToolbarBaseActionDescriptionMetadata.a = null;
    return WebGridToolbarBaseActionDescriptionMetadata;
}(Base));
export { WebGridToolbarBaseActionDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebGridToolbarBaseActionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
var WebGridToolbarBaseActionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebGridToolbarBaseActionDescriptionMetadata, _super);
    function WebGridToolbarBaseActionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridToolbarBaseActionDescriptionMetadata.b = function (a) {
        if (WebGridToolbarBaseActionDescriptionMetadata.a == null) {
            WebGridToolbarBaseActionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridToolbarBaseActionDescriptionMetadata.c(WebGridToolbarBaseActionDescriptionMetadata.a);
        }
        if (a.k(WebGridToolbarBaseActionDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridToolbarBaseActionDescriptionMetadata.a);
    };
    WebGridToolbarBaseActionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridToolbarBaseAction");
        a.item("__tagNameWC", "String:igc-grid-toolbar-base-action");
        a.item("__manageCollectionInMarkup", "Boolean");
        a.item("Name", "String");
        WebGridToolbarBaseActionDescriptionMetadata.e(a);
    };
    WebGridToolbarBaseActionDescriptionMetadata.d = function (a) {
        WebGridToolbarBaseActionDescriptionMetadata.b(a);
        a.ab("WebGridToolbarBaseAction", WebGridToolbarBaseActionDescriptionMetadata.a);
    };
    WebGridToolbarBaseActionDescriptionMetadata.e = function (a) {
        a.item("__tagNameWCSubstitutable", "String:igc-grid-toolbar-advanced-filtering,igc-grid-toolbar-exporter,igc-grid-toolbar-hiding,igc-grid-toolbar-pinning");
    };
    WebGridToolbarBaseActionDescriptionMetadata.$t = markType(WebGridToolbarBaseActionDescriptionMetadata, 'WebGridToolbarBaseActionDescriptionMetadata');
    WebGridToolbarBaseActionDescriptionMetadata.a = null;
    return WebGridToolbarBaseActionDescriptionMetadata;
}(Base));
export { WebGridToolbarBaseActionDescriptionMetadata };
